# `spoke`

A python library supporting pubsub and remote procedure calls.

# Isn't this just a bad dbus?

Actually this project started out as a bad ROS, but yes.

# Usage

See the various test cases in `tests` for examples
